==> gtk%2B2-2.18.7-i486-1sys.tgz: usr/doc/gtk+2-2.18.7/configure.sh <==
./configure \
  --prefix=/usr --enable-xkb \
  --sysconfdir=/etc --localstatedir=/var \
  --mandir=/usr/man \
  --with-xinput=yes \
  --with-libjasper \
   --enable-static --enable-shared  --build=i486-slackware-linux
#  letzte Zeile neu

# nachfolgendes noetig um pixbuffer load-Files fuer [extra]/etc/gtk-2.0 zu machen
make

# SYS Linux
###   ACHTUNG   im.multi.conf, /profile.d  und Inhalt von /etc/gtk-2.0/...   von letzter Version kopieren !!!!!!!!
# ... und nach dem compilieren vor dem packen ueberpruefen ob obige Ordner erneuert wurden, ggf. aus /etc/gtk-2.0 des
#     aktuellen Systems kopieren wo sie sein sollten ...
# profile.d aus voriger Version kopieren
#cp -f  /etc/gtk-2.0/im-multipress.conf /etc/gtk-2.0/im-multipress.conf.old   # falls alte config retten
make install   # zeitweiliges Installieren noetig damit neue pixbuf Files installiert und fuer nachfolgenden loader gefunden wd
libtool --finish /usr/lib/gtk-2.0/modules  > /dev/zero
libtool --finish /usr/lib/gtk-2.0/2.10.0/immodules  > /dev/zero
libtool --finish /usr/lib/gtk-2.0/2.10.0/engines  > /dev/zero
libtool --finish /usr/lib/gtk-2.0/2.10.0/filesystems  > /dev/zero
libtool --finish /usr/lib/gtk-2.0/2.10.0/loaders  > /dev/zero
libtool --finish /usr/lib/gtk-2.0/2.10.0/printbackends  > /dev/zero
libtool --finish /usr/lib/  > /dev/zero
ldconfig 
mkdir -p extra/etc/gtk-2.0  
#### mkdir -p extra/usr/share/icons     ####  neu 
#mkdir -p extra/etc/profile.d ;   cp /etc/profile.d/gtk+.*  ./extra/etc/profile.d  # falls nachfolgend keine Profile, die alten vom System nehmen
cp -aRf ./profile.d  ./extra/etc
cp -f /etc/gtk-2.0/im-multipress.conf ./extra/etc/gtk-2.0/im-multipress.conf     # falls kein neues da, das alte nehmen
#   ... dagegen im Paket und zu installierendem System vhd .conf evtl. nicht ueberkopieren
#      sondern neues als .new und in doinst.sh  , dann nachfolgende Anweisung ersetzen:
cp -f ./modules/input/im-multipress.conf ./extra/etc/gtk-2.0/im-multipress.conf       # falls neues da
#cp -f  /etc/gtk-2.0/im-multipress.conf.old /etc/gtk-2.0/im-multipress.conf   # falls alte config rueckkopieren
#   Wir erneuern es aber immer - lassen vorige Anweisung also drin - ,  
#  da weniger benutzergebunden als gtk-gebunden 
cp -f ./modules/input/im-multipress.conf ./extra/etc/gtk-2.0/im-multipress.conf.new  # muss im Hauptverz. sein  
./gtk/gtk-query-immodules-2.0 > ./extra/etc/gtk-2.0/gtk.immodules 
./gdk-pixbuf/gdk-pixbuf-query-loaders > ./extra/etc/gtk-2.0/gdk-pixbuf.loaders
#### ./gtk/gtk-update-icon-cache  -f -q -t  ./extra/usr/share/icons   # /hicolor   #### neu 


#make uninstall               # das installiert lassen schadet nichts
cp -aRf ./extra/etc  /        # ... sogar noch die eben erzeugten pixbuf loader kopieren und lassen
 
#  Hier kann man jetzt ggf. noch das gerade erzeugte ./extra/etc/gtk-2.0/gtk.immodules gegen ein zuvor abgespeichertes 
#  umfangreicheres ersetzen was auch die icons von momentan nicht installierten Paketen (zBsp scim) enthaelt und bei
#  Bedarf laedt
echo " Nun in /extra/etc/gtk-2.0 .conf 's ueberpruefen ob davon etwas"
echo "    subsidiaer zum vhd. verwendet werden soll, dann in .new umbenennen"
echo " Danach .auto.SlackBuild ausfuehren"

#./auto.SlackBuild

==> gtk%2B2-2.21.7-i486-1sys.tgz: usr/doc/gtk+2-2.21.7/configure.sh <==
./configure \
  --prefix=/usr --enable-xkb \
  --sysconfdir=/etc --localstatedir=/var \
  --mandir=/usr/man \
  --with-xinput=yes --disable-glibtest  \
   --enable-static --enable-shared  --build=i486-slackware-linux
#  letzte Zeile neu

# nachfolgendes noetig um pixbuffer load-Files fuer [extra]/etc/gtk-2.0 zu machen
make -i

# SYS Linux
###   ACHTUNG   im.multi.conf, /profile.d  und Inhalt von /etc/gtk-2.0/...   von letzter Version kopieren !!!!!!!!
# ... und nach dem compilieren vor dem packen ueberpruefen ob obige Ordner erneuert wurden, ggf. aus /etc/gtk-2.0 des
#     aktuellen Systems kopieren wo sie sein sollten ...
# profile.d aus voriger Version kopieren
#cp -f  /etc/gtk-2.0/im-multipress.conf /etc/gtk-2.0/im-multipress.conf.old   # falls alte config retten
make -i install   # zeitweiliges Installieren noetig damit neue pixbuf Files installiert und fuer nachfolgenden loader gefunden wd
libtool --finish /usr/lib/gtk-2.0/modules  > /dev/zero
libtool --finish /usr/lib/gtk-2.0/2.10.0/immodules  > /dev/zero
libtool --finish /usr/lib/gtk-2.0/2.10.0/engines  > /dev/zero
libtool --finish /usr/lib/gtk-2.0/2.10.0/filesystems  > /dev/zero
libtool --finish /usr/lib/gtk-2.0/2.10.0/loaders  > /dev/zero
libtool --finish /usr/lib/gtk-2.0/2.10.0/printbackends  > /dev/zero
libtool --finish /usr/lib/  > /dev/zero
ldconfig 
mkdir -p extra/etc/gtk-2.0  
#### mkdir -p extra/usr/share/icons     ####  neu 
#mkdir -p extra/etc/profile.d ;   cp /etc/profile.d/gtk+.*  ./extra/etc/profile.d  # falls nachfolgend keine Profile, die alten vom System nehmen
cp -aRf ./profile.d  ./extra/etc
cp -f /etc/gtk-2.0/im-multipress.conf ./extra/etc/gtk-2.0/im-multipress.conf     # falls kein neues da, das alte nehmen
#   ... dagegen im Paket und zu installierendem System vhd .conf evtl. nicht ueberkopieren
#      sondern neues als .new und in doinst.sh  , dann nachfolgende Anweisung ersetzen:
cp -f ./modules/input/im-multipress.conf ./extra/etc/gtk-2.0/im-multipress.conf       # falls neues da
#cp -f  /etc/gtk-2.0/im-multipress.conf.old /etc/gtk-2.0/im-multipress.conf   # falls alte config rueckkopieren
#   Wir erneuern es aber immer - lassen vorige Anweisung also drin - ,  
#  da weniger benutzergebunden als gtk-gebunden 
cp -f ./modules/input/im-multipress.conf ./extra/etc/gtk-2.0/im-multipress.conf.new  # muss im Hauptverz. sein  
./gtk/gtk-query-immodules-2.0 > ./extra/etc/gtk-2.0/gtk.immodules 
./gdk-pixbuf/gdk-pixbuf-query-loaders > ./extra/etc/gtk-2.0/gdk-pixbuf.loaders
#### ./gtk/gtk-update-icon-cache  -f -q -t  ./extra/usr/share/icons   # /hicolor   #### neu 


#make uninstall               # das installiert lassen schadet nichts
cp -aRf ./extra/etc  /        # ... sogar noch die eben erzeugten pixbuf loader kopieren und lassen
 
#  Hier kann man jetzt ggf. noch das gerade erzeugte ./extra/etc/gtk-2.0/gtk.immodules gegen ein zuvor abgespeichertes 
#  umfangreicheres ersetzen was auch die icons von momentan nicht installierten Paketen (zBsp scim) enthaelt und bei
#  Bedarf laedt
echo " Nun in /extra/etc/gtk-2.0 .conf 's ueberpruefen ob davon etwas"
echo "    subsidiaer zum vhd. verwendet werden soll, dann in .new umbenennen"
echo " Danach .auto.SlackBuild ausfuehren"

#./auto.SlackBuild
